GitlabClient class

Constructors

GitlabClient(String token, {String baseUrl = 'https://gitlab.com/api/v4'})

Properties

baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
latefinal

Methods

addDeployKey({required String projectId, required String title, required String key, bool canPush = false}) Future<Map<String, dynamic>?>
commitAction({required String filePath, required String content, String action = 'create'}) Map<String, String>
createProject(String name) Future<Map<String, dynamic>?>
createProjectVariable({required String projectId, required String key, required String value, bool masked = false}) Future<Map<String, dynamic>?>
makeCommit({required String projectId, required String message, required List<Map<String, String>> actions, String branch = 'master'}) Future<Map<String, dynamic>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateProjectVariable({required String projectId, required String key, required String value}) Future<Map<String, dynamic>?>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

httpSuccess(int statusCode) bool