GitlabClient class
Methods
-
addDeployKey({required String projectId, required String title, required String key, bool canPush = false})
→ Future<Map<String, dynamic>?>
-
-
commitAction({required String filePath, required String content, String action = 'create'})
→ Map<String, String>
-
-
createProject(String name)
→ Future<Map<String, dynamic>?>
-
-
createProjectVariable({required String projectId, required String key, required String value, bool masked = false})
→ Future<Map<String, dynamic>?>
-
-
makeCommit({required String projectId, required String message, required List<Map<String, String>> actions, String branch = 'master'})
→ Future<Map<String, dynamic>?>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateProjectVariable({required String projectId, required String key, required String value})
→ Future<Map<String, dynamic>?>
-